pub fn finish_and_set_server_timing_header(headers: &mut HeaderMap)Expand description
Add a final finish_request entry and write the collected timings to the
Server-Timing response header. No-op outside a server-timing context.
pub fn finish_and_set_server_timing_header(headers: &mut HeaderMap)Add a final finish_request entry and write the collected timings to the
Server-Timing response header. No-op outside a server-timing context.